@@ -15,8 +15,12 @@ class BaseContext(object):
     @classmethod
     def load_from_dict(cls, context_dict):
         context_type = context_dict['context_type']
-        print("debug778:context_type", cls.subclasses_dict, context_type)
-        context_class = cls.subclasses_dict[context_type]
+        # print("debug778:context_type", cls.subclasses_dict, context_type)
+        try:
+            context_class = cls.subclasses_dict[context_type]
+        except KeyError as e:
+            print('debug:context_type;subclasses_dict', context_type, cls.subclasses_dict)
+            raise e
         context = context_class.load_from_dict(context_dict)
         return context
 
