@@ -5,6 +5,7 @@ from dpdispatcher.base_context import BaseContext
 import os, sys, paramiko, json, uuid, tarfile, time, stat, shutil
 from glob import glob
 from dpdispatcher import dlog
+from dargs.dargs import Argument
 # from dpdispatcher.submission import Machine
 
 class SSHSession (object):
@@ -137,6 +138,28 @@ class SSHSession (object):
             self._sftp = self.ssh.open_sftp()
         return self._sftp
 
+    @staticmethod
+    def arginfo():
+        doc_hostname = 'hostname or ip of ssh connection.'
+        doc_username = 'username of target linux system'
+        doc_password = 'password of linux system'
+        doc_port = 'ssh connection port.'
+        doc_key_filename = 'key_filename used by ssh connection'
+        doc_passphrase = 'passphrase used by ssh connection'
+        doc_timeout = 'timeout of ssh connection'
+
+        ssh_remote_profile_args = [
+            Argument("hostname", str, optional=False, doc=doc_hostname),
+            Argument("username", str, optional=False, doc=doc_username),
+            Argument("password", str, optional=True, doc=doc_password),
+            Argument("port", int, optional=True, default=22, doc=doc_port),
+            Argument("key_filename", [str, None], optional=True, default=None, doc=doc_key_filename),
+            Argument("passphrase", [str, None], optional=True, default=None, doc=doc_passphrase),
+            Argument("timeout", int, optional=True, default=10, doc=doc_timeout)
+        ]
+        ssh_remote_profile_format = Argument("ssh_session", dict, ssh_remote_profile_args)
+        return ssh_remote_profile_format
+        
 
 class SSHContext(BaseContext):
     def __init__ (self,
@@ -195,7 +218,7 @@ class SSHContext(BaseContext):
         #     clean_asynchronously=jdata.get('clean_asynchronously', False),
         #     )
         return ssh_context
-    
+
     @property
     def ssh(self):
         return self.ssh_session.get_ssh_client()  
@@ -286,23 +309,25 @@ class SSHContext(BaseContext):
     def block_checkcall(self, 
                         cmd,
                         asynchronously=False,
-                        retry=0) :
+                        stderr_whitelist=None) :
+        """Run command with arguments. Wait for command to complete. If the return code
+        was zero then return, otherwise raise RuntimeError.
+
+        Parameters
+        ----------
+        cmd: str
+            The command to run.
+        asynchronously: bool, optional, default=False
+            Run command asynchronously. If True, `nohup` will be used to run the command.
+        """
         self.ssh_session.ensure_alive()
         if asynchronously:
             cmd = "nohup %s >/dev/null &" % cmd
         stdin, stdout, stderr = self.ssh_session.exec_command(('cd %s ;' % self.remote_root) + cmd)
         exit_status = stdout.channel.recv_exit_status() 
         if exit_status != 0:
-            if retry < 3:
-                # sleep 60 s
-                dlog.warning("Get error code %d in calling %s through ssh with job: %s . message: %s" %
-                        (exit_status, cmd, self.submission.submission_hash, stderr.read().decode('utf-8')))
-                dlog.warning("Sleep 60 s and retry the command...")
-                time.sleep(60)
-                return self.block_checkcall(cmd, asynchronously=asynchronously, retry=retry+1)
-            print('debug:self.remote_root, cmd', self.remote_root, cmd)
             raise RuntimeError("Get error code %d in calling %s through ssh with job: %s . message: %s" %
-                               (exit_status, cmd, self.submission.submission_hash, stderr.read().decode('utf-8')))
+                              (exit_status, cmd, self.submission.submission_hash, stderr.read().decode('utf-8')))
         return stdin, stdout, stderr    
 
     def block_call(self, 
