@@ -2,28 +2,35 @@
 # %%
 import os,sys,time,random,uuid,json,copy
 from typing import SupportsRound
+
+from dargs.dargs import Argument
 from dpdispatcher.JobStatus import JobStatus
-from dpdispatcher import dlog
+from dpdispatcher import dlog, machine
 from hashlib import sha1
 # from dpdispatcher.slurm import SlurmResources
 #%%
 default_strategy = dict(if_cuda_multi_devices=False)
 
 class Submission(object):
-    """submission represents the whole workplace, all the tasks to be calculated
+    """A submission represents a collection of tasks.
+    These tasks usually locate at a common directory.
+    And these Tasks may share common files to be uploaded and downloaded.
+    
     Parameters
     ----------
-    work_base : str
+    work_base : Path
         path-like, the base directory of the local tasks
-    resources : Resources
-        the machine resources (cpu or gpu) used to generate the slurm/pbs script
-    forward_common_files: list
-        the common files to be uploaded to other computers before the jobs begin
-    backward_common_files: list
-        the common files to be downloaded from other computers after the jobs finish
-    machine : machine
+    machine : Machine
         machine class object (for example, PBS, Slurm, Shell) to execute the jobs.
         The machine can still be bound after the instantiation with the bind_submission method.
+    resources : Resources
+        the machine resources (cpu or gpu) used to generate the slurm/pbs script
+    forward_common_files : list
+        the common files to be uploaded to other computers before the jobs begin
+    backward_common_files : list
+        the common files to be downloaded from other computers after the jobs finish
+    task_list : list of Task
+        a list of tasks to be run.
     """
     def __init__(self,
                 work_base,
@@ -327,22 +334,23 @@ class Submission(object):
                 raise RuntimeError("Recover failed.")
 
 class Task(object):
-    """a task is a sequential command to be executed, as well as its files to transmit forward and backward.
+    """A task is a sequential command to be executed, 
+    as well as the files it depends on to transmit forward and backward.
 
     Parameters
     ----------
-    command : str
+    command : Str
         the command to be executed.
-    task_work_path : path-like
+    task_work_path : Path
         the directory of each file where the files are dependent on.
-    forward_files : list of path-like
-        the files to be transmitted to other location before the calculation begins
-    backward_files : list of path-like
-        the files to be transmitted from other location after the calculation finished
-    log : str
-        the files to be transmitted from other location after the calculation finished
-    err : str
-        the files to be transmitted from other location after the calculation finished
+    forward_files : list of Path
+        the files to be transmitted to remote machine before the command execute.
+    backward_files : list of Path
+        the files to be transmitted from remote machine after the comand finished.
+    outlog : Str
+        the filename to which command redirect stdout
+    errlog : Str
+        the filename to which command redirect stderr
     """
     def __init__(self,
                 command,
@@ -386,7 +394,7 @@ class Task(object):
             the dictionary which contains the task information
         Returns
         -------
-        Task : task
+        task : Task
             the Task class instance converted from the task_dict
         """
         task=cls(**task_dict)
@@ -404,17 +412,18 @@ class Task(object):
         return task_dict
 
 class Job(object):
-    """Job is generated by Submission represnting a collection of task.
-    Each Job can generate a Shell, PBS, or a Slurm script to be submitted the job scheduler system or executed locally.
+    """Job is generated by Submission automatically.
+    A job ususally has many tasks and it may request computing resources from job scheduler systems.
+    Each Job can generate a script file to be submitted to the job scheduler system or executed locally.
 
     Parameters
     ----------
-    job_task_liste : list of Task
-        the tasks belong to the job
+    job_task_list : list of Task
+        the tasks belonging to the job
     resources : Resources
-        the machine resources. Passed from Submission when instantiating.
+        the machine resources. Passed from Submission when it constructs jobs.
     machine : machine
-        machine object to execute the job. Passed from Submission when instantiating.
+        machine object to execute the job. Passed from Submission when it constructs jobs.
     """
     def __init__(self,
                 job_task_list,
@@ -497,7 +506,7 @@ class Job(object):
             print("job: {job_hash} terminated; restarting job".format(job_hash=self.job_hash))
             if self.fail_count > 3:
                 raise RuntimeError("job:job {job} failed 3 times".format(job=self))
-            # self.fail_count += 1
+            self.fail_count += 1
             self.submit_job()
             self.get_job_state()
 
@@ -518,7 +527,7 @@ class Job(object):
         Parameters
         ----------
         if_static : bool
-            whether dump the job runtime infomation (job_id, job_state, fail_count, job_uuid) to the dictionary.
+            whether dump the job runtime infomation (job_id, job_state, fail_count, job_uuid etc.) to the dictionary.
 
         Returns
         -------
@@ -543,8 +552,11 @@ class Job(object):
 
     def submit_job(self):
         job_id = self.machine.do_submit(self)
-        self.register_job_id(job_id)
-        self.job_state = JobStatus.waiting
+        if job_id:
+            self.register_job_id(job_id)
+            self.job_state = JobStatus.waiting
+        else:
+            self.job_state = JobStatus.unsubmitted
 
     def job_to_json(self):
         # print('~~~~,~~~', self.serialize())
@@ -558,21 +570,28 @@ class Resources(object):
     Parameters
     ----------
     number_node : int
-        the number of node we need to do the calculation.
+        The number of node need for each `job`.
     cpu_per_node : int
         cpu numbers of each node.
     gpu_per_node : int
         gpu numbers of each node.
     queue_name : str
-        the job queue name of slurm or pbs job scheduler system.
+        The queue name of batch job scheduler system.
     group_size : int
-        the number of tasks in a job submitting script.
-    strategy['if_cuda_multi_devices'] : bool
-        experimentally, if there are multiple nvidia GPUS on the target computer, we want to compute the jobs to different GPUS.
-        With this option, dpdispatcher will manually allocate environment variable CUDA_VISIBLE_DEVICES to different task.
-        Usually, this option will be used with Task.task_need_resources variable simultaneously.
+        The number of `tasks` in a `job`.
+    custom_flags : list of Str
+        The extra lines pass to job submitting script header
+    strategy : dict
+        strategies we use to generation job submitting scripts.
+        if_cuda_multi_devices : bool
+            If there are multiple nvidia GPUS on the node, and we want to assign the tasks to different GPUS.
+            If true, dpdispatcher will manually export environment variable CUDA_VISIBLE_DEVICES to different task.
+            Usually, this option will be used with Task.task_need_resources variable simultaneously.
     para_deg : int
         Decide how many tasks will be run in parallel.
+        Usually run with `strategy['if_cuda_multi_devices']`
+    source_list : list of Path
+        The env file to be sourced before the command execution.
     """
     def __init__(self,
                 number_node,
@@ -654,7 +673,41 @@ class Resources(object):
         return resources
 
     @classmethod
-    def load_from_dict(cls, resource_dict):
-        return cls(**resource_dict)
+    def load_from_dict(cls, resources_dict):
+        
+        return cls(**resources_dict)
+
+    @staticmethod
+    def arginfo():
+        doc_number_node = 'The number of node need for each `job`'
+        doc_cpu_per_node = 'cpu numbers of each node assigned to each job.'
+        doc_gpu_per_node = 'gpu numbers of each node assigned to each job.'
+        doc_queue_name = 'The queue name of batch job scheduler system.'
+        doc_group_size = 'The number of `tasks` in a `job`.'
+        doc_custom_flags = 'The extra lines pass to job submitting script header'
+        doc_para_deg = 'Decide how many tasks will be run in parallel.'
+        doc_source_list = 'The env file to be sourced before the command execution.'
+        # doc_kwargs = 'extra key-value pair'
+
+        strategy_args = [
+            Argument("if_cuda_multi_devices", bool, optional=True, default=True)
+        ]
+        doc_strategy = 'strategies we use to generation job submitting scripts.'
+        strategy_format = Argument("strategy", dict, strategy_args, optional=True, doc=doc_strategy)
+
+        resources_args = [
+            Argument("number_node", int, optional=False, doc=doc_number_node),
+            Argument("cpu_per_node", int, optional=False, doc=doc_cpu_per_node),
+            Argument("gpu_per_node", int, optional=False, doc=doc_gpu_per_node),
+            Argument("queue_name", str, optional=False, doc=doc_queue_name),
+            Argument("group_size", int, optional=False, doc=doc_group_size),
+
+            Argument("custom_flags", list, optional=True, doc=doc_custom_flags),
+            # Argument("strategy", dict, optional=True, doc=doc_strategy,default=default_strategy),
+            strategy_format,
+            Argument("para_deg", int, optional=True, doc=doc_para_deg, default=1),
+            Argument("source_list", list, optional=True, doc=doc_source_list, default=[]),
+        ]
+        resources_format = Argument("resources", dict, resources_args)
+        return resources_format
 
-# %%
