@@ -19,7 +19,7 @@ class SampleClass(object):
         resources = Resources(number_node=1,
             cpu_per_node=4, 
             gpu_per_node=1,
-            queue_name="V100_8_32",
+            queue_name="T4_4_15",
             group_size=2,
             custom_flags=[],
             strategy={'if_cuda_multi_devices': False},
@@ -33,7 +33,7 @@ class SampleClass(object):
         resources_dict={'number_node': 1, 
             'cpu_per_node':4, 
             'gpu_per_node':1, 
-            'queue_name':'V100_8_32', 
+            'queue_name':'T4_4_15', 
             'group_size':2,
             'custom_flags':[],
             'strategy':{'if_cuda_multi_devices': False}, 
@@ -43,7 +43,6 @@ class SampleClass(object):
         }
         return resources_dict
 
-
     @classmethod
     def get_sample_task(cls):
         task = Task(command='lmp -i input.lammps', task_work_path='bct-1/', forward_files=['conf.lmp', 'input.lammps'], backward_files=['log.lammps'], outlog='log', errlog='err')
@@ -71,7 +70,8 @@ class SampleClass(object):
     def get_sample_empty_submission(cls):
         resources = cls.get_sample_resources()
         # print(task_list)
-        empty_submission = Submission(work_base='0_md/', 
+        empty_submission = Submission(work_base='0_md/',
+            machine=None,
             resources=resources, 
             forward_common_files=['graph.pb'], 
             backward_common_files=[])
@@ -120,7 +120,3 @@ class SampleClass(object):
             remote_root='tmp_slurm_dir/')
         slurm = Slurm(context=local_context)
         return slurm
-
-
-
-
